==> estateplat-common-1.2.4-20210824.024041-852-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJtcy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2017/3/6
 * @description 不动产家庭成员
 */
@Table(name = "bdc_jtcy")
public class BdcJtcy implements Serializable, InsertVo {
    @Id
    private String jtcyid;//家庭成员ID

    private String qlrid;//权利人ID

    private String jtcymc;//家庭成员名称

    private String sfzjzl;//身份证件种类

    private String zjh;//证件号

    private String txdz;//通讯地址

    private String xb;//性别

    private String lxdh;//联系电话

    private Integer xh;//序号

    private String yhzgx;//与户主关系

    private Date gxsj;//更新时间

    private String hkszd;//户口所在地

    private String gljtcyid;//关联家庭成员id

    private String fzjg;//发证机关'
    private String sshy;//所属行业'
    private String gj;//国家/地区'
    private String hjszss;//户籍所在省市'
    private String yb;//邮编'
    private String gzdw;//工作单位'
    private String dzyj;//电子邮件'
    private String sfgyr;//是否共有人 0：否 1：是 '
    private String bz;//备注'

    public String getFzjg() {
        return fzjg;
    }

    public void setFzjg(String fzjg) {
        this.fzjg = fzjg;
    }

    public String getSshy() {
        return sshy;
    }

    public void setSshy(String sshy) {
        this.sshy = sshy;
    }

    public String getGj() {
        return gj;
    }

    public void setGj(String gj) {
        this.gj = gj;
    }

    public String getHjszss() {
        return hjszss;
    }

    public void setHjszss(String hjszss) {
        this.hjszss = hjszss;
    }

    public String getYb() {
        return yb;
    }

    public void setYb(String yb) {
        this.yb = yb;
    }

    public String getGzdw() {
        return gzdw;
    }

    public void setGzdw(String gzdw) {
        this.gzdw = gzdw;
    }

    public String getDzyj() {
        return dzyj;
    }

    public void setDzyj(String dzyj) {
        this.dzyj = dzyj;
    }

    public String getSfgyr() {
        return sfgyr;
    }

    public void setSfgyr(String sfgyr) {
        this.sfgyr = sfgyr;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getJtcyid() {
        return jtcyid;
    }

    public void setJtcyid(String jtcyid) {
        this.jtcyid = jtcyid;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getJtcymc() {
        return jtcymc;
    }

    public void setJtcymc(String jtcymc) {
        this.jtcymc = jtcymc;
    }

    public String getSfzjzl() {
        return sfzjzl;
    }

    public void setSfzjzl(String sfzjzl) {
        this.sfzjzl = sfzjzl;
    }

    public String getZjh() {
        return zjh;
    }

    public void setZjh(String zjh) {
        this.zjh = zjh;
    }

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public String getYhzgx() {
        return yhzgx;
    }

    public void setYhzgx(String yhzgx) {
        this.yhzgx = yhzgx;
    }

    public Date getGxsj() {
        return gxsj;
    }

    public void setGxsj(Date gxsj) {
        this.gxsj = gxsj;
    }

    public String getHkszd() {
        return hkszd;
    }

    public void setHkszd(String hkszd) {
        this.hkszd = hkszd;
    }

    public String getGljtcyid() {
        return gljtcyid;
    }

    public void setGljtcyid(String gljtcyid) {
        this.gljtcyid = gljtcyid;
    }
}

==> estateplat-common-1.2.4-20220621.084244-1048-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJtcy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2017/3/6
 * @description 不动产家庭成员
 */
@Table(name = "bdc_jtcy")
public class BdcJtcy implements Serializable, InsertVo {
    @Id
    private String jtcyid;//家庭成员ID

    private String qlrid;//权利人ID

    private String jtcymc;//家庭成员名称

    private String sfzjzl;//身份证件种类

    private String zjh;//证件号

    private String txdz;//通讯地址

    private String xb;//性别

    private String lxdh;//联系电话

    private Integer xh;//序号

    private String yhzgx;//与户主关系

    private Date gxsj;//更新时间

    private String hkszd;//户口所在地

    private String gljtcyid;//关联家庭成员id

    private String fzjg;//发证机关
    private String sshy;//所属行业
    private String gj;//国家/地区
    private String hjszss;//户籍所在省市
    private String yb;//邮编
    private String gzdw;//工作单位
    private String dzyj;//电子邮件
    private String sfgyr;//是否共有人 0：否 1：是
    private String bz;//备注
    private String cbfbm;//承包方代码

    public String getFzjg() {
        return fzjg;
    }

    public void setFzjg(String fzjg) {
        this.fzjg = fzjg;
    }

    public String getSshy() {
        return sshy;
    }

    public void setSshy(String sshy) {
        this.sshy = sshy;
    }

    public String getGj() {
        return gj;
    }

    public void setGj(String gj) {
        this.gj = gj;
    }

    public String getHjszss() {
        return hjszss;
    }

    public void setHjszss(String hjszss) {
        this.hjszss = hjszss;
    }

    public String getYb() {
        return yb;
    }

    public void setYb(String yb) {
        this.yb = yb;
    }

    public String getGzdw() {
        return gzdw;
    }

    public void setGzdw(String gzdw) {
        this.gzdw = gzdw;
    }

    public String getDzyj() {
        return dzyj;
    }

    public void setDzyj(String dzyj) {
        this.dzyj = dzyj;
    }

    public String getSfgyr() {
        return sfgyr;
    }

    public void setSfgyr(String sfgyr) {
        this.sfgyr = sfgyr;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getJtcyid() {
        return jtcyid;
    }

    public void setJtcyid(String jtcyid) {
        this.jtcyid = jtcyid;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getJtcymc() {
        return jtcymc;
    }

    public void setJtcymc(String jtcymc) {
        this.jtcymc = jtcymc;
    }

    public String getSfzjzl() {
        return sfzjzl;
    }

    public void setSfzjzl(String sfzjzl) {
        this.sfzjzl = sfzjzl;
    }

    public String getZjh() {
        return zjh;
    }

    public void setZjh(String zjh) {
        this.zjh = zjh;
    }

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public String getYhzgx() {
        return yhzgx;
    }

    public void setYhzgx(String yhzgx) {
        this.yhzgx = yhzgx;
    }

    public Date getGxsj() {
        return gxsj;
    }

    public void setGxsj(Date gxsj) {
        this.gxsj = gxsj;
    }

    public String getHkszd() {
        return hkszd;
    }

    public void setHkszd(String hkszd) {
        this.hkszd = hkszd;
    }

    public String getGljtcyid() {
        return gljtcyid;
    }

    public void setGljtcyid(String gljtcyid) {
        this.gljtcyid = gljtcyid;
    }

    public String getCbfbm() {
        return cbfbm;
    }

    public void setCbfbm(String cbfbm) {
        this.cbfbm = cbfbm;
    }
}
